# Guardian Service specific dependencies only
# Common dependencies are provided by smarbuy/abi-image:latest

# Security and cryptography
cryptography>=41.0.0

# OPA client
opa-python-client>=1.3.0

# Policy validation
jsonschema>=4.17.0